Package: forestplot
Version: 3.2.0
Title: Advanced Forest Plot Using 'grid' Graphics
Authors@R: c(person(given = "Max",
                    family = "Gordon",
                    role = c("aut", "cre"),
                    email = "max@gforge.se"),
             person(given = "Thomas",
                    family = "Lumley",
                    role = c("aut", "ctb")))
Description: Allows the creation of forest plots with advanced features, such as
    multiple confidence intervals per row, customizable fonts for individual text
    elements, and flexible confidence interval drawing. It also supports mixing
    text with mathematical expressions. The package extends the application of
    forest plots beyond traditional meta-analyses, offering a more general version
    of the original 'rmeta' package’s forestplot() function. It relies heavily on
    the 'grid' package for rendering the plots.
License: GPL-2
URL: https://gforge.se/packages/
BugReports: https://github.com/gforge/forestplot/issues
Biarch: yes
Depends: R (>= 4.1.0), grid, checkmate, abind
Suggests: dplyr, Gmisc, Greg, knitr, purrr, rlang, rmarkdown, rmeta,
        rms, testthat, tibble, tidyr, tidyselect, tidyverse
Encoding: UTF-8
NeedsCompilation: no
VignetteBuilder: knitr
RoxygenNote: 7.3.3
LazyData: true
Packaged: 2026-03-03 20:42:19 UTC; max
Author: Max Gordon [aut, cre],
  Thomas Lumley [aut, ctb]
Maintainer: Max Gordon <max@gforge.se>
Repository: CRAN
Date/Publication: 2026-03-04 06:30:59 UTC
Built: R 4.6.0; ; 2026-04-26 12:06:58 UTC; unix
