# Generated by roxygen2: do not edit by hand

S3method(forestplot,data.frame)
S3method(forestplot,default)
S3method(forestplot,grouped_df)
S3method(heightDetails,xaxis)
S3method(plot,forestplot_legend)
S3method(plot,gforge_forestplot)
S3method(plot,gforge_forestplot_lines)
S3method(print,gforge_forestplot)
export(forestplot)
export(fpColors)
export(fpDrawBarCI)
export(fpDrawCircleCI)
export(fpDrawDiamondCI)
export(fpDrawNormalCI)
export(fpDrawPointCI)
export(fpDrawSummaryCI)
export(fpLegend)
export(fpShapesGp)
export(fpTxtGp)
export(fp_add_header)
export(fp_add_lines)
export(fp_align_center)
export(fp_align_left)
export(fp_align_right)
export(fp_align_where)
export(fp_append_row)
export(fp_decorate_graph)
export(fp_extract_labels)
export(fp_extract_labeltext)
export(fp_insert_row)
export(fp_set_favors)
export(fp_set_style)
export(fp_set_summary)
export(fp_set_zebra_style)
export(fp_span)
export(fp_span_where)
export(fp_txt_bold)
export(fp_txt_gp)
export(fp_txt_italic)
export(fp_txt_plain)
export(fp_txt_where)
export(getTicks)
export(prGetShapeGp)
import(grid)
importFrom(abind,adrop)
importFrom(checkmate,assert)
importFrom(checkmate,assert_class)
importFrom(checkmate,assert_matrix)
importFrom(checkmate,assert_number)
importFrom(checkmate,assert_vector)
importFrom(checkmate,check_array)
importFrom(checkmate,check_integer)
importFrom(checkmate,check_matrix)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.cur)
importFrom(graphics,par)
importFrom(grid,gpar)
importFrom(stats,na.omit)
importFrom(utils,head)
importFrom(utils,tail)
